@@ -5,7 +5,7 @@ package Math::BigFloat::Constant;
 use strict;
 use warnings;
 
-our $VERSION = 1.09;
+our $VERSION = '1.10';
 
 use Math::BigFloat '1.999802';
 our @ISA = qw( Math::BigFloat );
@@ -172,7 +172,44 @@ C<Math::BigFloat> object.
 
 =head1 BUGS
 
-None discovered yet.
+Please report any bugs or feature requests to
+C<bug-math-bigint at rt.cpan.org>, or through the web interface at
+L<https://rt.cpan.org/Ticket/Create.html?Queue=Math-BigInt-Constant>
+(requires login).
+We will be notified, and then you'll automatically be notified of
+progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Math::BigInt::Constant
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Math-BigInt-Constant>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Math-BigInt-Constant>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/Math-BigInt-Constant>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Math-BigInt-Constant/>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=Math-BigInt-Constant>
+
+=back
 
 =head1 SEE ALSO
 
